@@ -11,7 +11,7 @@ use DateTime::TimeZone 0.06;
 use DateTime::TimeZone::UTC;
 use DateTime::TimeZone::Floating;
 
-$VERSION = '0.16006';
+$VERSION = '0.16009';
 $VERSION = eval $VERSION;
 
 our @ISA = ('DateTime::Format::Builder');
@@ -26,7 +26,7 @@ DateTime::Format::Pg - Parse and format PostgreSQL dates and times
 
   my $dt = DateTime::Format::Pg->parse_datetime( '2003-01-16 23:12:01' );
 
-  # 2003-01-16T23:12:01+0200
+  # 2003-01-16 23:12:01
   DateTime::Format::Pg->format_datetime($dt);
 
 =head1 DESCRIPTION
@@ -209,7 +209,7 @@ my $pg_dateonly_german =
 #
 my $pg_timeonly =
 {
-  regex		=> qr/^(\d{2,}):(\d{2,}):(\d{2,})(\.\d+)? *([-\+][\d:]+)?$/,
+  regex		=> qr/^T?(\d{2,}):(\d{2,}):(\d{2,})(\.\d+)? *([-\+][\d:]+)?$/,
   params 	=> [ qw( hour    minute  second nanosecond  time_zone) ],
   extra		=> { year => '1970' },
   postprocess	=> [ \&_fix_timezone, \&_fix_nanosecond ],
@@ -225,7 +225,7 @@ my $pg_timeonly =
 #
 my $pg_datetime_iso =
 {
-  regex		=> qr/^(\d{4,})-(\d{2,})-(\d{2,}) (\d{2,}):(\d{2,}):(\d{2,})(\.\d+)? *([-\+][\d:]+)?( BC)?$/,
+  regex		=> qr/^(\d{4,})-(\d{2,})-(\d{2,})[ T](\d{2,}):(\d{2,}):(\d{2,})(\.\d+)? *([-\+][\d:]+)?( BC)?$/,
   params 	=> [ qw( year    month    day      hour     minute  second nanosecond time_zone       era) ],
   postprocess 	=> [ \&_fix_era, \&_fix_timezone, \&_fix_nanosecond ],
 };
@@ -338,14 +338,24 @@ sub _fix_timezone {
   # Numerical time zone
   #
   
-  elsif($args{'parsed'}->{'time_zone'} =~ m/^[-\+](\d+)(:\d+)?$/) {
-    $args{'parsed'}->{'time_zone'} .= ':00' if !$2 && length($1) == 2;
+  elsif($args{'parsed'}->{'time_zone'} =~ m/^([-\+])(\d+)(?::(\d+))?(?::(\d+))?$/) {
+    my $tz;
+    if (length($2) == 2) {
+        # regular hour notation
+        my ($min, $sec) = ($3 || '00', $4 || '00');
+        $tz = sprintf "%s%02d:%02d:%02d", $1, $2, $min, $sec;
+    } else {
+        $tz = "$1$2";
+    }
+    $args{'parsed'}->{'time_zone'} = $tz;
   }
   
   # Non-numerical time zone returned, which can be ambiguous :(
   #
   else
   {
+    # XXX This barfs because 'self' may not necessarily be initialized
+    # Need to fix it
     my $stz = $args{'self'}->_server_tz($args{'args'} ? @{$args{'args'}} : ());
     $args{'parsed'}->{'time_zone'} = $stz || 'floating';
   }
@@ -409,7 +419,7 @@ option is set correctly (i.e. same as the PostgreSQL server).  The same is true
 for time zones and the 'australian_timezones' option in all modes but 'ISO'.
 
 The default DateStyle, 'ISO', will always produce unambiguous results
-and is also parsed most efficiently by this parser class. I stronlgly
+and is also parsed most efficiently by this parser class. I strongly
 recommend using this setting unless you have a good reason not to.
 
 =over 4
@@ -429,7 +439,7 @@ If given an improperly formatted string, this method may die.
 =cut
 
 # sub parse_datetime {
-#   *** created autmatically ***
+#   *** created automatically ***
 # }
 
 =item * parse_timestamptz($string,...)
@@ -452,7 +462,7 @@ If given an improperly formatted string, this method may die.
 =cut
 
 # sub parse_timestamptz {
-#   *** created autmatically ***
+#   *** created automatically ***
 # }
 
 *parse_timestamp_with_time_zone = \&parse_timestamptz;
@@ -497,7 +507,7 @@ If given an improperly formatted string, this method may die.
 =cut
 
 # sub parse_timetz {
-#   *** created autmatically ***
+#   *** created automatically ***
 # }
 
 *parse_time_with_time_zone = \&parse_timetz;
@@ -535,7 +545,7 @@ If given an improperly formatted string, this method may die.
 =cut
 
 # sub parse_date {
-#   *** generated autmatically ***
+#   *** generated automatically ***
 # }
 
 =item * parse_duration($string)
@@ -824,7 +834,7 @@ As a general rules, none of these limitations apply to the 'ISO' output
 format.  It is strongly recommended to use this format (and to use
 PostgreSQL's to_char function when another output format that's not
 supposed to be handled by a parser of this class is desired). 'ISO' is
-the default but you are advised to explicitly set it at the beginnig of
+the default but you are advised to explicitly set it at the beginning of
 the session by issuing a SET DATESTYLE TO 'ISO'; command in case the
 server administrator changes that setting.
 
@@ -863,7 +873,7 @@ This problem does not occur when using the ISO or German output format
 C<DateTime::Duration> stores months, days, minutes and seconds
 separately. PostgreSQL only stores months and seconds and disregards the
 irregular length of days due to DST switching and the irregular length
-of minutes due to leap seconds. Therefore, it is not possitble to store
+of minutes due to leap seconds. Therefore, it is not possible to store
 C<DateTime::Duration> objects as SQL INTERVALs without the loss of some
 information.
 
